This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch master updated. glibc-2.24-379-g7773556


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, master has been updated
       via  7773556dfb2bf62f7b6deda66fa3821a3bcdbf3e (commit)
      from  afcf3cd8ebff8fed79238a2d1b95338c4606b1ee (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sourceware.org/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=7773556dfb2bf62f7b6deda66fa3821a3bcdbf3e

commit 7773556dfb2bf62f7b6deda66fa3821a3bcdbf3e
Author: Zack Weinberg <zackw@panix.com>
Date:   Wed Nov 16 14:18:32 2016 -0500

    Correct comments in string.h re strcoll_l, strxfrm_l.
    
    	* string/string.h: Remove obsolete comment stating that
    	strcoll_l and strxfrm_l have not yet been standardized.

diff --git a/ChangeLog b/ChangeLog
index b2e5b68..25e1da1 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2016-11-16  Zack Weinberg  <zackw@panix.com>
+
+	* string/string.h: Remove obsolete comment stating that
+	strcoll_l and strxfrm_l have not yet been standardized.
+
 2016-11-16  Adhemerval Zanella  <adhemerval.zanella@linaro.org>
 
 	* hurd/hurd.h (__hurd_fail_noerrno): New function.
diff --git a/string/string.h b/string/string.h
index 57deaa4..b103e64 100644
--- a/string/string.h
+++ b/string/string.h
@@ -154,15 +154,13 @@ extern size_t strxfrm (char *__restrict __dest,
 __END_NAMESPACE_STD
 
 #ifdef __USE_XOPEN2K8
-/* The following functions are equivalent to the both above but they
-   take the locale they use for the collation as an extra argument.
-   This is not standardsized but something like will come.  */
 # include <xlocale.h>
 
 /* Compare the collated forms of S1 and S2 using rules from L.  */
 extern int strcoll_l (const char *__s1, const char *__s2, __locale_t __l)
      __THROW __attribute_pure__ __nonnull ((1, 2, 3));
-/* Put a transformation of SRC into no more than N bytes of DEST.  */
+/* Put a transformation of SRC into no more than N bytes of DEST,
+   using sorting rules from L.  */
 extern size_t strxfrm_l (char *__dest, const char *__src, size_t __n,
 			 __locale_t __l) __THROW __nonnull ((2, 4));
 #endif

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog       |    5 +++++
@@ -154,15 +154,13 @@ extern size_t strxfrm (char *__restrict __dest,
 # include <xlocale.h>
 
-/* Compare the collated forms of S1 and S2 using rules from L.  */
+/* Compare the collated forms of S1 and S2, using sorting rules from L.  */
 extern int strcoll_l (const char *__s1, const char *__s2, __locale_t __l)
      __THROW __attribute_pure__ __nonnull ((1, 2, 3));
 string/string.h |    8 +++-----
 2 files changed, 8 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]